@@ -247,7 +247,7 @@ class Explorer:
             subtitle=subtitle,
             subtitle_align="right",
             style="white",
-            box=box_type
+            box=box_type,
         )
 
     @property
@@ -315,7 +315,7 @@ class Explorer:
             subtitle=f"([magenta]{self.dict_index + 1}[/magenta]/[magenta]{len(self.cached_obj.filtered_dict)}[/magenta])",
             subtitle_align="right",
             style="white",
-            box=box_type
+            box=box_type,
         )
 
     @property
@@ -388,7 +388,7 @@ class Explorer:
             subtitle=f"([magenta]{self.list_index + 1}[/magenta]/[magenta]{len(self.cached_obj.filtered_list)}[/magenta])",
             subtitle_align="right",
             style="white",
-            box=box_type
+            box=box_type,
         )
 
     def explore_selected_object(self) -> Optional[CachedObject]:
